@@ -1,6 +1,13 @@
 use thiserror::Error;
 
+use std::io;
+use std::net;
+use std::string::FromUtf8Error;
+
+pub type Result<T> = std::result::Result<T, Error>;
+
 #[derive(Debug, Error, PartialEq)]
+#[non_exhaustive]
 pub enum Error {
     #[error("mDNS: failed to join multicast group")]
     ErrJoiningMulticastGroup,
@@ -52,14 +59,29 @@ pub enum Error {
     ErrCompressedSrv,
     #[error("empty builder msg")]
     ErrEmptyBuilderMsg,
-
-    #[allow(non_camel_case_types)]
     #[error("{0}")]
-    new(String),
+    Io(#[source] IoError),
+    #[error("utf-8 error: {0}")]
+    Utf8(#[from] FromUtf8Error),
+    #[error("parse addr: {0}")]
+    ParseIp(#[from] net::AddrParseError),
+    #[error("{0}")]
+    Other(String),
 }
 
-impl Error {
-    pub fn equal(&self, err: &anyhow::Error) -> bool {
-        err.downcast_ref::<Self>().map_or(false, |e| e == self)
+#[derive(Debug, Error)]
+#[error("io error: {0}")]
+pub struct IoError(#[from] pub io::Error);
+
+// Workaround for wanting PartialEq for io::Error.
+impl PartialEq for IoError {
+    fn eq(&self, other: &Self) -> bool {
+        self.0.kind() == other.0.kind()
+    }
+}
+
+impl From<io::Error> for Error {
+    fn from(e: io::Error) -> Self {
+        Error::Io(IoError(e))
     }
 }
