@@ -2,8 +2,6 @@ use super::*;
 use crate::error::*;
 use crate::message::packer::*;
 
-use anyhow::Result;
-
 // A TXTResource is a txt Resource record.
 #[derive(Default, Debug, Clone, PartialEq)]
 pub struct TxtResource {
@@ -46,7 +44,7 @@ impl ResourceBody for TxtResource {
             off = new_off;
             // Check if we got too many bytes.
             if length < n + t.as_bytes().len() + 1 {
-                return Err(Error::ErrCalcLen.into());
+                return Err(Error::ErrCalcLen);
             }
             n += t.len() + 1;
             txts.push(t);
